svn commit: r232257 - in head: share/man/man4 sys/dev/usb sys/dev/usb/net

Kevin Lo kevlo at FreeBSD.org
Tue Feb 28 15:45:42 UTC 2012


Author: kevlo
Date: Tue Feb 28 15:45:42 2012
New Revision: 232257
URL: http://svn.freebsd.org/changeset/base/232257

Log:
  Add support for the MCS7832
  
  Obtained from:	OpenBSD

Modified:
  head/share/man/man4/mos.4
  head/sys/dev/usb/net/if_mos.c
  head/sys/dev/usb/net/if_mosreg.h
  head/sys/dev/usb/usbdevs

Modified: head/share/man/man4/mos.4
==============================================================================
--- head/share/man/man4/mos.4	Tue Feb 28 15:12:26 2012	(r232256)
+++ head/share/man/man4/mos.4	Tue Feb 28 15:45:42 2012	(r232257)
@@ -20,7 +20,7 @@
 .Os
 .Sh NAME
 .Nm mos
-.Nd Moschip MCS7730/MCS7840 USB Ethernet driver
+.Nd Moschip MCS7730/MCS7830/MCS7832 USB Ethernet driver
 .Sh SYNOPSIS
 To compile this driver into the kernel,
 place the following lines in your
@@ -44,9 +44,9 @@ if_mos_load="YES"
 The
 .Nm
 driver provides support for USB Ethernet adapters based on the 
-Moschip MCS7730/MCS7830 chipset.
+Moschip MCS7730/MCS7830/MCS7832 chipset.
 .Pp
-The adapters that contain the Moschip MCS7730/MCS7830 chipset
+The adapters that contain the Moschip MCS7730/MCS7830/MCS7832 chipset
 will operate at 100Base-TX and full-duplex.
 .Pp
 The Moschip contains a 10/100

Modified: head/sys/dev/usb/net/if_mos.c
==============================================================================
--- head/sys/dev/usb/net/if_mosreg.h	Tue Feb 28 15:12:26 2012	(r232256)
+++ head/sys/dev/usb/net/if_mosreg.h	Tue Feb 28 15:45:42 2012	(r232257)
@@ -152,6 +152,7 @@
 
 #define	MCS7730	0x0001
 #define	MCS7830	0x0002
+#define	MCS7832	0x0004
 
 #define	MOS_INC(x, y)           (x) = (x + 1) % y
 

Modified: head/sys/dev/usb/usbdevs
==============================================================================
--- head/sys/dev/usb/usbdevs	Tue Feb 28 15:12:26 2012	(r232256)
+++ head/sys/dev/usb/usbdevs	Tue Feb 28 15:45:42 2012	(r232257)
@@ -2306,6 +2306,7 @@ product MOSCHIP MCS7703		0x7703	MCS7703 
 product MOSCHIP MCS7730		0x7730  MCS7730 Ethernet
 product MOSCHIP MCS7820		0x7820	MCS7820 Serial Port Adapter
 product MOSCHIP MCS7830		0x7830	MCS7830 Ethernet
+product MOSCHIP MCS7832		0x7832	MCS7832 Ethernet
 product MOSCHIP MCS7840		0x7840	MCS7840 Serial Port Adapter
 
 /* Motorola products */


More information about the svn-src-all mailing list
--- head/sys/dev/usb/net/if_mos.c	Tue Feb 28 15:12:26 2012	(r232256)
+++ head/sys/dev/usb/net/if_mos.c	Tue Feb 28 15:45:42 2012	(r232257)
@@ -82,7 +82,7 @@
 __FBSDID("$FreeBSD$");
 
 /*
  * Moschip MCS7730/MCS7830 USB to Ethernet controller
  * The datasheet is available at the following URL:
  * http://www.moschip.com/data/products/MCS7830/Data%20Sheet_7830.pdf
  */
@@ -149,6 +149,7 @@ SYSCTL_INT(_hw_usb_mos, OID_AUTO, debug,
 static const STRUCT_USB_HOST_ID mos_devs[] = {
 	{USB_VPI(USB_VENDOR_MOSCHIP, USB_PRODUCT_MOSCHIP_MCS7730, MCS7730)},
 	{USB_VPI(USB_VENDOR_MOSCHIP, USB_PRODUCT_MOSCHIP_MCS7830, MCS7830)},
+	{USB_VPI(USB_VENDOR_MOSCHIP, USB_PRODUCT_MOSCHIP_MCS7832, MCS7832)},
 	{USB_VPI(USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_LN030, MCS7830)},
 };
 
@@ -715,6 +716,8 @@ mos_attach(device_t dev)
 		MOS_DPRINTFN("model: MCS7730");
 	} else if (sc->mos_flags & MCS7830) {
 		MOS_DPRINTFN("model: MCS7830");
+	} else if (sc->mos_flags & MCS7832) {
+		MOS_DPRINTFN("model: MCS7832");
 	}
 	error = uether_ifattach(ue);
 	if (error) {
@@ -82,7 +82,7 @@
 
 /*
- * Moschip MCS7730/MCS7830 USB to Ethernet controller
+ * Moschip MCS7730/MCS7830/MCS7832 USB to Ethernet controller
  * The datasheet is available at the following URL:
  * http://www.moschip.com/data/products/MCS7830/Data%20Sheet_7830.pdf

Modified: head/sys/dev/usb/net/if_mosreg.h
==============================================================================